@@ -1,6 +1,7 @@
 /*
  * raid_io.h : Utility for the Linux Multiple Devices driver
  *             Copyright (C) 1997 Ingo Molnar, Miguel de Icaza, Gadi Oxman
+ *	       Copyright (C) 1998 Erik Troan
  *
  * Externaly visible RAID IO operations interface.
  *
@@ -8,14 +9,19 @@
  * sources.
  */
 
+#include "common.h"
+#include "raidlib.h"
+
 void progress (unsigned long blocks, unsigned long current);
 
 long long raidseek (unsigned int fd, unsigned long blk);
-extern void print_sb (md_superblock_t *sb);
-extern int analyze_sb (void);
-extern int init_set (void);
+extern void print_sb (mdp_super_t *sb);
+int analyze_sb (mdu_version_t * ver, enum mkraidFunc func, 
+	md_cfg_entry_t * cfg, int forceSanity,
+	int upgradeArray, int forceResync);
+extern int init_set (md_cfg_entry_t * p);
 extern int check_active (md_cfg_entry_t *p);
-extern int read_sb (void);
-extern int write_sb (int old);
+extern int read_sb (md_cfg_entry_t *p);
+int write_sb (md_cfg_entry_t * p, int old);
 
 
